@@ -1,12 +1,12 @@
 #' plots result over map
 #'
-#' plots track over map with probability cloud. Can plot only part of the track if dates are specified
+#' plots track over map with probability cloud. Can plot only part of the track if dates are specified. Note that you can use it only after obtaining and registering in you current session Google Api Key. For details on the API key check [here](http://ornithologyexchange.org/forums/topic/38315-mapflightrggmap-error).
 #' @param Result FLightR result object obtained from \code{\link{run.particle.filter}}
-#' @param dates either NULL if all twilights should be included or data.frame with first colum - start of the period and second end of the period. Each line represents a new period
-#' @param plot.cloud Shlould probability cloud be plotted? If TRUE cloud is estimated by \code{\link[ggplot2]{stat_density2d}}
+#' @param dates either NULL if all twilights should be included or data.frame with first column - start of the period and second end of the period. Each line represents a new period
+#' @param plot.cloud Should probability cloud be plotted? If TRUE cloud is estimated by \code{\link[ggplot2]{stat_density2d}}
 #' @param map.options options passed to \code{\link[ggmap]{get_map}}, note that \code{zoom} option is defined separately
 #' @param plot.options plotting options. Not defined yet!
-#' @param save.options ptions passed to \code{\link[ggplot2]{ggsave}}. Filename should be defined here.
+#' @param save.options options passed to \code{\link[ggplot2]{ggsave}}. Filename should be defined here.
 #' @param zoom Zoom for map. If 'auto' FLightR will try to find optimal zoom level by downloading different size maps and checking whether all the points fit the map.
 #' @param return.ggobj Should ggobj be returned for subsequent checks and/or replotting
 #' @param seasonal.colors if true points of the track will have seasonal colors
@@ -41,17 +41,30 @@
 #'            nParticles=1e3, known.last=TRUE,
 #'            precision.sd=25, check.outliers=FALSE)
 #'
-#' map.FLightR.ggmap(Result, seasonal.donut.location=NULL, zoom=6, save=FALSE) 
+#'\dontrun{
+#' map.FLightR.ggmap(Result, seasonal.donut.location=NULL, zoom=6, save=FALSE)
+#'} 
 #' # for this short track without variance seasonal donut does not work,
 #' # but for normall track it will.
 #' @author Eldar Rakhimberdiev
 #' @export map.FLightR.ggmap
 map.FLightR.ggmap<-function(Result, dates=NULL, plot.cloud=TRUE, map.options=NULL, plot.options=NULL, save.options=NULL, zoom="auto", return.ggobj=FALSE, seasonal.colors=TRUE, seasonal.donut.location='topleft', seasonal.donut.proportion=0.5, save=TRUE) {
 if (!is.null(plot.options)) warning("plot options are not in use yet. Let me know what you would like to have here.")
+
+if (utils::packageVersion('ggmap')[1]<2.7) { stop('map.FLightR.ggmap function works only with ggmap >= 2.7.x') }
+if (!ggmap::has_goog_key()) stop('From August 2018 Google allows to use Google maps only for users with the API key, please get one and proceed as described here: http://ornithologyexchange.org/forums/topic/38315-mapflightrggmap-error/')
 # dates should be a data.frame with first point - starting dates and last column end dates for periods
 
 # ggsave.options is a list that will be will be directly passed to ggsave
 
+Opt<-options('ggmap')
+if(is.null(Opt$ggmap$google$account_type)) Opt$ggmap$google$account_type<-'standard'
+if(is.null(Opt$ggmap$google$day_limit)) Opt$ggmap$google$day_limit<-2500
+if(is.null(Opt$ggmap$google$second_limit)) Opt$ggmap$google$day_limit<-50
+if(is.null(Opt$ggmap$google$client)) Opt$ggmap$google$client<-NA
+if(is.null(Opt$ggmap$google$signature)) Opt$ggmap$google$signature<-NA
+options('ggmap'= Opt$ggmap)
+
 # select twilights to plot
 	 if (is.null(dates)) {
 	     twilights.index<-1:length(Result$Results$Points.rle)
@@ -69,20 +82,21 @@ if (!is.null(plot.options)) warning("plot options are not in use yet. Let me kno
          for (twilight in 1:length(twilights.index)) {
              All.Points[Points_rle[[twilight]]$values]<-All.Points[Points_rle[[twilight]]$values] + Points_rle[[twilight]]$lengths
          }
-		 Points<-Result$Spatial$Grid[All.Points>0,][sample.int(length(All.Points[All.Points>0]), size = 10000, replace = TRUE, prob = All.Points[All.Points>0]), 1:2]
+		 Points<-Result$Spatial$Grid[All.Points>0,,drop=FALSE][sample.int(length(All.Points[All.Points>0]), size = 10000, replace = TRUE, prob = All.Points[All.Points>0]), 1:2]
 	}
 	
 	# background map
 	
 	# check whether Grid was over dateline:
-	overdateline<-ifelse(attr(Result$Spatial$Grid, 'left')>	attr(Result$Spatial$Grid, 'right'), TRUE, FALSE)
-	
+    overdateline<-ifelse(attr(Result$Spatial$Grid, 'left')>	attr(Result$Spatial$Grid, 'right'), TRUE, FALSE)	
 	if (overdateline) {
 	location<-cbind(
 	            min(Result$Results$Quantiles$Medianlon[twilights.index][Result$Results$Quantiles$Medianlon[twilights.index]>0]),
 				min(Result$Results$Quantiles$Medianlat[twilights.index]),
 				max(Result$Results$Quantiles$Medianlon[twilights.index][Result$Results$Quantiles$Medianlon[twilights.index]<0]),
 				max(Result$Results$Quantiles$Medianlat[twilights.index]))
+	if (!is.finite(location[1])) location[1] <-180
+	if (!is.finite(location[3])) location[3] <- -180
 	} else {			
 	location<-cbind(
 	            min(Result$Results$Quantiles$Medianlon[twilights.index]),
@@ -152,10 +166,11 @@ if (!is.null(plot.options)) warning("plot options are not in use yet. Let me kno
 	 p<-p+ ggplot2::scale_fill_gradient(low = "green", high = "red") 
 	 p<-p+ ggplot2::scale_alpha(range = c(0.00, 0.25), guide = FALSE) 
      }
-	 p<-p+ggplot2::coord_map(projection="mercator", 
-     xlim=c(attr(background, "bb")$ll.lon, attr(background, "bb")$ur.lon),
-     ylim=c(attr(background, "bb")$ll.lat, attr(background, "bb")$ur.lat)) +
-     ggplot2::theme(legend.position = "none", axis.title = ggplot2::element_blank(), text = ggplot2::element_text(size = 12))
+
+	#p<-p+ggplot2::coord_map(projection="mercator", 
+    # xlim=c(attr(background, "bb")$ll.lon, attr(background, "bb")$ur.lon),
+    # ylim=c(attr(background, "bb")$ll.lat, attr(background, "bb")$ur.lat))
+    p<-p+ ggplot2::theme(legend.position = "none", axis.title = ggplot2::element_blank(), text = ggplot2::element_text(size = 12))
     
     # here I plot track for selected dates
 	
@@ -211,7 +226,7 @@ if (!is.null(plot.options)) warning("plot options are not in use yet. Let me kno
 
 #' plots result by longitude and latitude
 #'
-#' This function plots result by latitude and longitude in either vertical or horizontal layout
+#' This function plots result by latitude and longitude in either vertical or horizontal layout.
 #' @param Result FLightR result object obtained from \code{\link{run.particle.filter}}
 #' @param scheme either 'vertical' or 'horizontal' layouts
 #' return NULL
@@ -396,17 +411,17 @@ get_time_spent_buffer<-function(Result, dates=NULL, percentile=0.5, r=NULL) {
   return(list(Buffer=Buff_comb_simpl, nPoints=length(Points)))
   }
 
-#' plots resulting track over map with uncertainty shown by spave utilisation distribution
+#' plots resulting track over map with uncertainty shown by space utilisation distribution
 #' 
-#' May be use not only for the whole track but for a set of specific dates, e.g. to show spatial uncertainty during migration
+#' May be use not only for the whole track but for a set of specific dates, e.g. to show spatial uncertainty during migration. Note that you can use it only after obtaining and registering in you current session Google Api Key. For details on the API key check [here](http://ornithologyexchange.org/forums/topic/38315-mapflightrggmap-error).
 #' 
 #' @param Result FLightR result object obtained from \code{\link{run.particle.filter}}
-#' @param dates Use NULL if all twilights will be used for plotting, one integer if specific twilight should be plotted (line number in Result$Results$Quantiles). Use data.frame with first colum - start of the period and second - end of the period and each line represents a new period to plot specific periods, e.g. wintering or migration.
+#' @param dates Use NULL if all twilights will be used for plotting, one integer if specific twilight should be plotted (line number in Result$Results$Quantiles). Use data.frame with first column - start of the period and second - end of the period and each line represents a new period to plot specific periods, e.g. wintering or migration.
 #' @param map.options options passed to \code{\link[ggmap]{get_map}}, note that \code{zoom} option is defined separately
 #' @param percentiles Probability breaks for utilisation distribution
 #' @param zoom Zoom for map. If 'auto' FLightR will try to find optimal zoom level by downloading different size maps and checking whether all the points fit the map.
-#' @param geom_polygon.options passed to \code{\link[ggplot2]{geom_polygon}}
-#' @param save.options ptions passed to \code{\link[ggplot2]{ggsave}}. Filename should be defined here.
+#' @param geom_polygon.options options passed to \code{\link[ggplot2]{geom_polygon}}
+#' @param save.options options passed to \code{\link[ggplot2]{ggsave}}. Filename should be defined here.
 #' @param color.palette colors for probability contours. Either NULL or \code{\link[grDevices]{colorRampPalette}} object
 #' @param use.palette should the same colors be used for polygon boundaries as for polygon filling?
 #' @param background if provided will be used as a background. Must be created by \code{link[ggmap]{get_map}}
@@ -444,12 +459,28 @@ get_time_spent_buffer<-function(Result, dates=NULL, percentile=0.5, r=NULL) {
 #'            nParticles=1e3, known.last=TRUE,
 #'            precision.sd=25, check.outliers=FALSE)
 #'
+#'\dontrun{
 #' plot_util_distr(Result, zoom=6, save=FALSE)
+#'}
 #'
 #' @author Eldar Rakhimberdiev
 #' @export plot_util_distr
 plot_util_distr<-function(Result, dates=NULL, map.options=NULL, percentiles=c(0.4, 0.6, 0.8), zoom="auto", geom_polygon.options=NULL, save.options=NULL, color.palette=NULL, use.palette=TRUE, background=NULL, plot=TRUE, save=TRUE, add.scale.bar=FALSE, scalebar.options=NULL) {
 
+if (utils::packageVersion('ggmap')[1]<2.7) {stop('plot_util_distr function works only with ggmap >= 2.7.x')}
+
+if (!ggmap::has_goog_key()) stop('From August 2018 Google allows to use Google maps only for users with the API key, please get one and proceed as described here: http://ornithologyexchange.org/forums/topic/38315-mapflightrggmap-error/')
+
+
+Opt<-options('ggmap')
+if(is.null(Opt$ggmap$google$account_type)) Opt$ggmap$google$account_type<-'standard'
+if(is.null(Opt$ggmap$google$day_limit)) Opt$ggmap$google$day_limit<-2500
+if(is.null(Opt$ggmap$google$second_limit)) Opt$ggmap$google$day_limit<-50
+if(is.null(Opt$ggmap$google$client)) Opt$ggmap$google$client<-NA
+if(is.null(Opt$ggmap$google$signature)) Opt$ggmap$google$signature<-NA
+options('ggmap'= Opt$ggmap)
+
+
    # for r cmd check
    long<-NA
    lat<-NA
@@ -639,8 +670,8 @@ seasonal_donut<-function() {
 #' plots specific likelihood surface over map
 #' @details function plots likelihoods before particle filter run, so these are pure results of calibrations without any movement model
 #' @param object either output from \code{\link{make.prerun.object}} or \code{\link{run.particle.filter}}
-#' @param date either NULL or a date (possibly with time) closest to the twilight you wan tto be plotted
-#' @param twilight.index number of likelohood surface to be plotted 
+#' @param date either NULL or a date (possibly with time) closest to the twilight you wan to be plotted
+#' @param twilight.index number of likelihood surface to be plotted 
 #' @examples
 #' File<-system.file("extdata", "Godwit_TAGS_format.csv", package = "FLightR")
 #' # to run example fast we will cut the real data file by 2013 Aug 20
